load

Function load 

pub unsafe fn load(path: impl AsRef<Path>) -> Result<Module>
Load an xabi module from a native library path.

Safety

Loading arbitrary native code is unsafe. The caller must trust the module at path and ensure any loaded exports are used with their matching ABI.

let module = unsafe { xabi::load("./module.so") }?;