SendPtr

Struct SendPtr 

pub struct SendPtr<T> { /* private fields */ }
Sendable wrapper for raw pointers that are only dereferenced on a known-safe thread.

This is useful when a raw ABI pointer must be moved into an async task but the caller controls where it is dereferenced.

let mut value = 1_u32;
let ptr = xabi::SendPtr::new(&mut value as *mut u32);
let raw = ptr.as_ptr();
unsafe { *raw = 2 };
assert_eq!(value, 2);

Implementations

Source

impl<T> SendPtr<T>

pub fn new(ptr: *mut T) -> Self

Wrap a raw mutable pointer.

pub fn as_ptr(self) -> *mut T

Return the wrapped raw pointer.