XabiOption

Struct XabiOption 

#[repr(C)]
pub struct XabiOption { pub size: usize, pub abi_version: u32, pub is_some: u8, pub payload: XabiOwnedBytes, }
Optional xabi payload.

is_some distinguishes None from Some(T) even when T encodes to an empty payload, such as an empty string or empty byte vector.

Fields

size: usize

Size of this structure in bytes.

abi_version: u32

ABI version for this structure.

is_some: u8

1 when payload contains an encoded value, 0 for None.

payload: XabiOwnedBytes

Owned encoded payload for the contained value.

Implementations

Source

impl XabiOption

pub const ABI_VERSION: u32 = ABI_VERSION

ABI version expected by this structure.

pub const MIN_SIZE: usize

Minimum required size for the current option representation.

pub const FULL_SIZE: usize

Full size of this option representation.

pub fn none() -> Self

Create a None wire value.

pub fn some(payload: XabiOwnedBytes) -> Self

Create a Some wire value from an encoded payload.

pub fn validate(&self) -> Result<()>

Validate the option layout and discriminant.