pub unsafe fn load(path: impl AsRef<Path>) -> Result<Module>Expand description
Load an xabi module from a native library path.
Safety
Loading arbitrary native code is unsafe. The caller must trust the module at
path and ensure any loaded exports are used with their matching ABI.
let module = unsafe { xabi::load("./module.so") }?;