#[repr(C)]pub struct XabiOption {
pub size: usize,
pub abi_version: u32,
pub is_some: u8,
pub payload: XabiOwnedBytes,
}Expand description
Optional xabi payload.
is_some distinguishes None from Some(T) even when T encodes to an
empty payload, such as an empty string or empty byte vector.
Fields
size: usizeSize of this structure in bytes.
abi_version: u32ABI version for this structure.
is_some: u81 when payload contains an encoded value, 0 for None.
payload: XabiOwnedBytesOwned encoded payload for the contained value.
Implementations
Sourceimpl XabiOption
impl XabiOption
Sourcepub const ABI_VERSION: u32 = ABI_VERSION
pub const ABI_VERSION: u32 = ABI_VERSION
ABI version expected by this structure.
Sourcepub fn some(payload: XabiOwnedBytes) -> Self
pub fn some(payload: XabiOwnedBytes) -> Self
Create a Some wire value from an encoded payload.